/*
 * Copyright 2013 Palantir Technologies, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
*/

"use strict";

module.exports = function(grunt) {

  var Linter = require("tslint");

  grunt.registerMultiTask("tslint", "A linter for TypeScript.", function() {
    var options = this.options({
      formatter: "prose"
    });

    var retValue = true;
    // Iterate over all specified file groups.
    this.filesSrc.forEach(function(filepath) {
      if (!grunt.file.exists(filepath)) {
        grunt.log.warn('Source file "' + filepath + '" not found.');
      } else {
        var contents = grunt.file.read(filepath);
        var linter = new Linter(filepath, contents, options);

        var result = linter.lint();

        if(result.failureCount > 0) {
          result.output.split("\n").forEach(function(line) {
            if(line !== "") {
              grunt.log.error(line);
            }
          });
          retValue = false;
        }
      }
    });
    return retValue;
  });

};
